# VideoRecording


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**mp4_upload_url** | **str** |  | [readonly] 
**mp4_size** | **int** |  | [readonly] 
**cloud_sync_done** | **bool** |  | [optional] 
**finalize_start** | **datetime** |  | [optional] 
**finalize_end** | **datetime** |  | [optional] 
**recording_start** | **datetime** |  | [optional] 
**recording_end** | **datetime** |  | [optional] 
**gcode_file_name** | **str** |  | [optional] 
**mp4_file** | **str** |  | [readonly] 
**user** | **int** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


